@@ -23,6 +23,7 @@ from octobot_tentacles_manager.loaders.tentacle_loading import (
     get_resources_path,
     get_tentacle_module_path,
     get_tentacles_classes_names_from_tentacle_module,
+    get_tentacles_classes_names_for_type,
     get_documentation_file_path,
     get_documentation,
     get_tentacle,
@@ -37,6 +38,7 @@ __all__ = [
     "get_resources_path",
     "get_tentacle_module_path",
     "get_tentacles_classes_names_from_tentacle_module",
+    "get_tentacles_classes_names_for_type",
     "get_documentation_file_path",
     "get_documentation",
     "get_tentacle",
